"""This application install the given ELK components."""

import argparse
import logging
import sys
from logging.handlers import RotatingFileHandler
from typing import Callable, NamedTuple

import urllib3

def main() -> int:
    """The main program the configure_elk package."""

    parser = argparse.ArgumentParser(
        prog=__name__, description="Install specified ELK packages."
    )

    parser.add_argument(
        "-m",
        "--master",
        dest="elk_master",
        help=(
            "the (resolvable) elk-master name, "
            "the one that will run Elasticsearch/Kibana"
        ),
        required=True,
    )

    parser.add_argument(
        "-l",
        "--log",
        dest="log_level",
        choices=["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"],
        default="DEBUG",
        help="Set the logging level",
    )
    args = parser.parse_args()

    log_path = "/var/log/editshare/configure_elk.log"
    handlers = [
        RotatingFileHandler(log_path, maxBytes=10000000, backupCount=5)
    ]
    logging.basicConfig(
        format="%(asctime)s %(levelname)-8s %(message)s",
        level=args.log_level,
        handlers=handlers,
    )
    logging.info("CMD: %s", sys.argv)

    # Install what we were instructed to install.

    # Signal success to the caller.
    return 0


if __name__ == "__main__":
    # We make a lot of insecure HTTPS requests,
    # and the warning obscure real issues.
    # So turn off those warnings.
    urllib3.disable_warnings()
    main()
