""" This application will do any required reindexing """

import argparse
import datetime
import json
import logging
import sys
from logging import StreamHandler
from logging.handlers import RotatingFileHandler
from typing import List

import requests
import urllib3
from requests.auth import HTTPBasicAuth



def main() -> int:
    """The main program the configure_elk package."""

    # Commandline processing.
    parser = argparse.ArgumentParser(
        prog=__name__, description="EditShare Elasticsearch reindexer."
    )
    parser.add_argument("--stdout")
    parser.add_argument(
        "--level",
        choices=["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"],
        default="DEBUG",
        help="Set the logging level",
    )
    args = parser.parse_args()

    # Send log lines to /var/log/editshare/configure_elk.log
    log_path = "/var/log/editshare/elk_reindexer.log"

    if args.stdout:
        handlers = [
            RotatingFileHandler(log_path, maxBytes=10000000, backupCount=5),
            StreamHandler(sys.stdout),
        ]
    else:
        handlers = [
            RotatingFileHandler(log_path, maxBytes=10000000, backupCount=5)
        ]

    logging.basicConfig(
        format="%(asctime)s %(levelname)-8s %(message)s",
        level=args.level,
        handlers=handlers,
    )

    # Do the reindex

    # Signal success to the caller.
    return 0


if __name__ == "__main__":
    # We make a lot of insecure HTTPS requests,
    # and the warning obscure real issues.
    # So turn off those warnings.
    urllib3.disable_warnings()
    main()
